import { ButtonStyle, APIMessageComponentEmoji, APIButtonComponent, EmojiFormat, APIEmbedFooter, APIEmbedImage, APIEmbedThumbnail, APIEmbedAuthor, APIEmbedField, APIEmbed, APIMessageComponent, APIAllowedMentions, APIWebhook } from 'discord-api-types/v10';

declare class Button {
    label?: string;
    style?: ButtonStyle;
    custom_id?: string;
    url?: string;
    emoji?: APIMessageComponentEmoji;
    disabled?: boolean;
    constructor(data?: APIButtonComponent);
    setLabel(label: string): this;
    setStyle(style: ButtonStyle): this;
    setCustomId(custom_id: string): this;
    setURL(url: string): this;
    setEmoji(emoji: EmojiFormat): this;
    setDisabled(disabled: boolean): this;
    toJSON(): {
        type: number;
        label: string | undefined;
        style: number;
        custom_id: string;
        url: string | undefined;
        emoji: APIMessageComponentEmoji | undefined;
        disabled: boolean | undefined;
    };
}

declare class Embed {
    title?: string;
    description?: string;
    url?: string;
    timestamp?: string | Date;
    color?: number;
    footer?: APIEmbedFooter;
    image?: APIEmbedImage;
    thumbnail?: APIEmbedThumbnail;
    author?: APIEmbedAuthor;
    fields: APIEmbedField[];
    constructor(data?: APIEmbed);
    setTitle(title: string): this;
    setDescription(description: string): this;
    setColor(color: string | number): this;
    setURL(url: string): this;
    setTimestamp(timestamp?: Date): this;
    setFooter(iconURL: string | undefined, text: string | any[]): this;
    setImage(imageURL: string): this;
    setThumbnail(url: string): this;
    setAuthor(name: string | any[], url: string | undefined, iconURL: string | undefined): this;
    addField(name: string | any[], value: string | any[], inline?: boolean | undefined): this;
    addFields(fields: APIEmbedField[]): this;
    toJSON(): {
        title: string | undefined;
        description: string | undefined;
        url: string | undefined;
        color: number | undefined;
        timestamp: string | undefined;
        footer: APIEmbedFooter | undefined;
        image: APIEmbedImage | undefined;
        thumbnail: APIEmbedThumbnail | undefined;
    };
}

declare class MessageBuilder {
    data: {
        embeds: APIEmbed[];
        components: APIMessageComponent[];
        content?: string;
    };
    constructor(content?: string);
    addEmbed(embed: Embed | APIEmbed): this;
    removeEmbed(index: number): this;
    clearEmbeds(): this;
    addComponent(component: APIMessageComponent | Button): this;
    toJSON(): Object;
}

interface WebhookOptions {
    url: string;
}
interface User {
    id: string;
    username: string;
    discriminator: string;
    avatar: string;
}
interface WebhookObject {
    guild_id?: string;
    channel_id?: string;
    user?: User;
    token?: string;
    name: string;
    avatar: string;
    id: string;
    application_id?: string;
    url?: string;
}
interface ModifyWebhookOptions {
    name?: string;
    avatar?: string;
    channel_id?: string;
}
interface ExecuteWebhookData {
    content?: string;
    username?: string;
    avatar_url?: string;
    tts?: boolean;
    embeds?: APIEmbed[];
    allowed_mentions?: APIAllowedMentions;
    components?: APIMessageComponent[];
    flags?: number;
    thread_name?: string;
    files?: DiscordFile[];
}
interface DiscordFile {
    name: string;
    file: Buffer;
}

declare class Webhook {
    private options;
    defaultPayload?: {};
    constructor(options: WebhookOptions);
    get(): Promise<APIWebhook>;
    setUsername(username: string): void;
    setAvatar(avatar: string): void;
    modify(options: WebhookOptions): Promise<any>;
    delete(): Promise<any>;
    execute(data: ExecuteWebhookData): Promise<any>;
    private request;
}

export { Button, DiscordFile, Embed, ExecuteWebhookData, MessageBuilder, ModifyWebhookOptions, User, Webhook, WebhookObject, WebhookOptions };
